#include "parser.h"
#include "printer.h"
#include "polynomial.h"
#include "division.h"
#include "buchberger.h"
#include "wallideal.h"
#include "lp.h"
#include "reversesearch.h"
#include "termorder.h"
#include "gfanapplication.h"
#include "wallideal.h"
#include "polyhedralcone.h"

class WeightVectorApplication : public GFanApplication
{
  FieldOption theFieldOption;
public:
  const char *helpText()
  {
    return "This program computes a strictly positive interior point of the cone given by the marked Groebner basis on the input.\n";
  }
  WeightVectorApplication()
  {
    registerOptions();
  }
  
  char *name()
  {
    return "_weightvector";
  }

  int main()
  {
    LpSolver::printList(Stderr);
    lpSetSolver("cddgmp");
    
    FileParser P(Stdin);

    PolynomialSet g=P.parsePolynomialSet();
    IntegerVectorList normals=wallInequalities(g);
    int n=g.numberOfVariablesInRing();

    //    AsciiPrinter(Stdout).printVector(PolyhedralCone(normals,IntegerVectorList(),n).relativeInteriorPoint(true));
    AsciiPrinter(Stdout).printVector(intersection(PolyhedralCone(normals,IntegerVectorList(),n),PolyhedralCone::positiveOrthant(n)).relativeInteriorPoint(false));
    AsciiPrinter(Stdout).printNewLine();
    //interiorPoint(normals,Stdout,true);

    return 0;
  }
};

static WeightVectorApplication theApplication;
