#ifndef EP_XFIG_H_INCLUDED
#define EP_XFIG_H_INCLUDED

#include "enumeration.h"

#include <list>

class XfigEnumerationPrinter: public EnumerationFilePrinter
{
  struct Point
  {
    float x,y,z;
    float dot(const Point &p)const{return x*p.x+y*p.y+z*p.z;}
    bool isInside(const Point &p)const{return dot(p)>0;}
    Point(float x_, float y_, float z_):x(x_),y(y_),z(z_){}
    void print()const;
    Point intersect(Point a, Point b)const
    {
      float A=dot(a);
      float B=dot(b);
      float cA=B/(B-A);
      float cB=-A/(B-A);

      return Point(a.x*cA+b.x*cB,a.y*cA+b.y*cB,a.z*cA+b.z*cB);
    }
  };
  typedef list<Point> Polygon;
  int basisCounter;
  void kickPoint(const Point &p);
  void printPolygon(const Polygon &p);
  void drawPolygon(const Polygon &vertices);
  Polygon intersect(const Polygon &polygon, const Point &normal);
  bool largerTriangle;
  int variableShift;
public:
  XfigEnumerationPrinter(bool _largerTriangle=false);
  bool basis(const PolynomialSet &groebnerBasis);
  string extension();
  void beginEnumeration(const PolynomialSet &groebnerBasis);
  void endEnumeration();
  void onOpened();
  void onClose();
  void onClosed();
  void setVariableShift(int shift);
};

#endif
