#include "subspace.h"

#include "division.h"
#include "buchberger.h"

static Polynomial vectorToPolynomial(IntegerVector const &v)
{
  static Field* field;

  if(!field)field=Field::find("GmpRationals"); // this is a bit stupid. We should add a field_rationals header file instead
  assert(field);

  Polynomial ret;

  for(int i=0;i<v.size();i++)
    if(v[i])
      {
	ret+=Term(field->zHomomorphism(v[i]),IntegerVector::standardVector(v.size(),i));
      }

  return ret;
}


Subspace::Subspace(IntegerVectorList const &generators, int ambientDimension)
{
  n=ambientDimension;
  if(n==-1)
    {
      assert(!generators.empty());
      n=generators.begin()->size();
    }
  for(IntegerVectorList::const_iterator i=generators.begin();i!=generators.end();i++)
    {
      assert(i->size()==n);
      basis.push_back(vectorToPolynomial(*i));
    }
  buchberger(&basis,LexicographicTermOrder());
}

bool Subspace::contains(IntegerVector const &v)const
{
  assert(v.size()==n);

  return division(vectorToPolynomial(v),basis,LexicographicTermOrder()).isZero();
}


int Subspace::dimension()
{
  return basis.size();
}


int Subspace::ambientDimension()
{
  return n;
}


Subspace sum(Subspace const &a, Subspace const &b)
{
  Subspace ret=a;

  ret.basis.insert(ret.basis.end(),b.basis.begin(),b.basis.end());
  buchberger(&ret.basis,LexicographicTermOrder());

  return ret;
}
